Get Started With aWherePy
=========================

aWherePy is a python package built to retrieve, extract, and format weather and agronomic data from the aWhere API.

aWherePy Module and Function Documentation
------------------------------------------

All functions are included in the 7 awherepy modules:

- agronomics
- crops
- fields
- grid
- models
- plantings
- weather

Install aWherePy
----------------

Dependencies
~~~~~~~~~~~~

aWherePy has several Python package dependencies.  Use the awhere-python conda environment (LINK TO ENVIRONMENT GITHUB HERE) to ensure that you have all of the required dependencies needed to run aWherePy.

Alternatively, use pip to install aWherePy.

``pip install awherepy``

Once aWherePy is installed you can import it into Python.

    >>> import awherepy as aw

You can also import the individual modules as follows:

    >>> import awherepy.agronomics as awa
    >>> import awherepy.crops as awc
    >>> import awherepy.fields as awf
    >>> import awherepy.grid as awg
    >>> import awherepy.models as awm
    >>> import awherepy.plantings as awp
    >>> import awherepy.weather as aww

Data
~~~~

Example data to work with aWherePy can be bound here: LINK TO EXAMPLE DATA
